==> polarion_rest_api_client-1.2.0-py3-none-any.whl: polarion_rest_api_client/open_api_client/models/workitem_approvals_list_post_request_data_item_attributes.py <==
# Copyright DB InfraGO AG and contributors
# SPDX-License-Identifier: Apache-2.0

from typing import Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.workitem_approvals_list_post_request_data_item_attributes_status import (
    WorkitemApprovalsListPostRequestDataItemAttributesStatus,
)
from ..types import UNSET, Unset

T = TypeVar("T", bound="WorkitemApprovalsListPostRequestDataItemAttributes")


@_attrs_define
class WorkitemApprovalsListPostRequestDataItemAttributes:
    """
    Attributes:
        status (Union[Unset, WorkitemApprovalsListPostRequestDataItemAttributesStatus]):  Example: waiting.
    """

    status: Union[
        Unset, WorkitemApprovalsListPostRequestDataItemAttributesStatus
    ] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(
        init=False, factory=dict
    )

    def to_dict(self) -> Dict[str, Any]:
        status: Union[Unset, str] = UNSET
        if not isinstance(self.status, Unset):
            status = self.status.value

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if status is not UNSET:
            field_dict["status"] = status

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        _status = d.pop("status", UNSET)
        status: Union[
            Unset, WorkitemApprovalsListPostRequestDataItemAttributesStatus
        ]
        if isinstance(_status, Unset):
            status = UNSET
        else:
            status = WorkitemApprovalsListPostRequestDataItemAttributesStatus(
                _status
            )

        workitem_approvals_list_post_request_data_item_attributes_obj = cls(
            status=status,
        )

        workitem_approvals_list_post_request_data_item_attributes_obj.additional_properties = (
            d
        )
        return workitem_approvals_list_post_request_data_item_attributes_obj

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> polarion_rest_api_client-1.4.1-py3-none-any.whl: polarion_rest_api_client/open_api_client/models/workitem_approvals_list_post_request_data_item_attributes.py <==
# Copyright DB InfraGO AG and contributors
# SPDX-License-Identifier: Apache-2.0

from collections.abc import Mapping
from typing import Any, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.workitem_approvals_list_post_request_data_item_attributes_status import (
    WorkitemApprovalsListPostRequestDataItemAttributesStatus,
)
from ..types import UNSET, Unset

T = TypeVar("T", bound="WorkitemApprovalsListPostRequestDataItemAttributes")


@_attrs_define
class WorkitemApprovalsListPostRequestDataItemAttributes:
    """
    Attributes:
        status (Union[Unset, WorkitemApprovalsListPostRequestDataItemAttributesStatus]):  Example: waiting.
    """

    status: Union[
        Unset, WorkitemApprovalsListPostRequestDataItemAttributesStatus
    ] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(
        init=False, factory=dict
    )

    def to_dict(self) -> dict[str, Any]:
        status: Union[Unset, str] = UNSET
        if not isinstance(self.status, Unset):
            status = self.status.value

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if status is not UNSET:
            field_dict["status"] = status

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        _status = d.pop("status", UNSET)
        status: Union[
            Unset, WorkitemApprovalsListPostRequestDataItemAttributesStatus
        ]
        if isinstance(_status, Unset):
            status = UNSET
        else:
            status = WorkitemApprovalsListPostRequestDataItemAttributesStatus(
                _status
            )

        workitem_approvals_list_post_request_data_item_attributes_obj = cls(
            status=status,
        )

        workitem_approvals_list_post_request_data_item_attributes_obj.additional_properties = (
            d
        )
        return workitem_approvals_list_post_request_data_item_attributes_obj

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
